# Retentioneering
Framework and Tools for user trajectories analysis.

To start use our package, please, see the [documentation](https://retentioneering.github.io/retentioneering-tools/)

## Installation

### Python and Jupyter

Firstly, you need to install python and Jupyter.
We supports only python 3.
For quick start better to install [Anaconda](https://www.anaconda.com/).

### Python package

- You can install our package using pip.

```bash
pip3 install retentioneering
```

- Or directly from source

    ```bash
    git clone path-to-our-rep.git
    cd retentioneering-framework
    python3 setup.py install --user
    ```

## Introduction
It's better to start with this things to understand Retentioneering.

### [First steps](https://retentioneering.github.io/retentioneering-tools/_build/html/early_steps.html#first-steps)
Configuration, preparing your data graph basics.

### [Temporal funnel](https://retentioneering.github.io/retentioneering-tools/_build/html/early_steps.html#temporal-funnel)
Also known as Step Matrix.

### [Clustering](https://retentioneering.github.io/retentioneering-tools/_build/html/early_steps.html#clustering)
Clutermap, TSNE projections, target events in clustering, cluster graphs.

### [Supervised classifier](https://retentioneering.github.io/retentioneering-tools/_build/html/early_steps.html#supervised-classifier)
Supervised learning, sklearn-api.

## Mobile application cases
In this example we will perform an analysis for the app focusing on investigation why people remove app.

### [Analysis](https://retentioneering.github.io/retentioneering-tools/_build/html/mobile-app-case.html#analysis)
Step matrix and clustering.
### [Predict application remove](https://retentioneering.github.io/retentioneering-tools/_build/html/mobile-app-case.html#predict-app-remove)

## Documentation
### [Packages and Subpackages](https://retentioneering.github.io/retentioneering-tools/_build/html/retentioneering.html)
